# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

> **Note:** This project uses [*Towncrier*](https://towncrier.readthedocs.io/) to manage the changelog automatically. **Do not manually edit or commit changes to this file.**

{% include '_draft_changelog.md' ignore missing %}

<!-- BEGIN RELEASED CHANGELOG -->

## [v1.0.2](https://github.com/jd-35656/readme-credly-badges/tree/v1.0.2) - 2025-10-17

### Fixed

- Improved internal module documentation and usage examples. ([#5](https://github.com/jd-35656/readme-credly-badges/issues/5))


## [v1.0.1](https://github.com/jd-35656/readme-credly-badges/tree/v1.0.1) - 2025-10-17

No significant changes.


## [v1.0.0](https://github.com/jd-35656/readme-credly-badges/tree/v1.0.0) - 2025-10-17

### Added

- Initial project scaffolding with core, CLI, tests, docs, configs, and CI setup ([#1](https://github.com/jd-35656/readme-credly-badges/issues/1))
- Core and CLI implementations with supporting exceptions and utilities. ([#3](https://github.com/jd-35656/readme-credly-badges/issues/3))

### Changed

- Updated tests to cover new core and CLI features. ([#3](https://github.com/jd-35656/readme-credly-badges/issues/3))

### Fixed

- improve GitHub Actions workflows for caching and release versioning, update changelog. ([#3](https://github.com/jd-35656/readme-credly-badges/issues/3))
